<?php
/*
Plugin Name: elpix Rate Post in Comment
Version: 1.1.0.1
Plugin URI: http://www.elpix.de/kompetenz/wordpress-cms/plugin-rate-post-in-comment/ ‎
Description: A plugin to add star rating for posts to the comment form.
Author: elpix
Author URI: http://www.elpix.de
Text Domain: elpix-rpic
*/
/*  Copyright 2007-2013 elpix (email: info at elpix.de)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

/**
 *	Init plugin
 * 
 *	@author Kay Köhler <kk@elpix.de>
 */
add_action('plugins_loaded', 'elpix_rate_post_in_init');
function elpix_rate_post_in_init() 
{
	$plugin_dir = dirname(plugin_basename(__FILE__));
	load_plugin_textdomain( 'elpix-rpic', false, $plugin_dir );
}

/**
*	Enqueue plugin style-file and js file for frontend
* 
*	@author Kay Köhler <kk@elpix.de>
*/
add_action( 'wp_enqueue_scripts', 'elpix_rate_post_add_my_stylesheet' );
function elpix_rate_post_add_my_stylesheet() 
{
	wp_register_style( 'elpix-rate-post-style', plugins_url('elpix-rate-post.css', __FILE__) );
	wp_enqueue_style( 'elpix-rate-post-style' );
	wp_enqueue_script( 'elpix-rate-post-js', plugins_url( 'elpix-rate-post.js', __FILE__ ) , array( 'jquery' ), '2013-07-16' );
}

/**
*
*	Enqueue plugin style-file for backend
* 
*	@author Kay Köhler <kk@elpix.de>
*/
add_action( 'admin_init', 'elpix_rate_post_admin_init' );
function elpix_rate_post_admin_init() 
{      
	wp_register_style( 'elpix-rate-post-style', plugins_url('elpix-rate-post.css', __FILE__) );
	wp_enqueue_style( 'elpix-rate-post-style' );
}

/**
 *	Display rating in commentform for logged in users and not logged in users
 * 
 *	@author Kay Köhler <kk@elpix.de>
 *	TODO: Possibility to choose for who it is visible as an option in Backend
 * 
 */
// Add fields after default fields above the comment box, always visible
//Visible for logged in users
add_action( 'comment_form_logged_in_after', 'elpix_rate_post_rating_field' );
//Visible for not logged in users
add_action( 'comment_form_after_fields', 'elpix_rate_post_rating_field' );
function elpix_rate_post_rating_field () 
{
	?>
	<p class="comment-form-rating">
		<label for="rating"><?php _e( 'Bewertung', 'elpix-rpic' ); ?><span class="required">*</span></label>
		<span class="comment-rating-box">
			<?php for( $i=1; $i <= 5; $i++ ) {
				echo '<a href="#'.$i.'" title="'.$i.'" id="star_'.$i.'" class="star_link star_'.$i.'">'.$i.'</a>';
			}?>
			<input type="hidden" name="elpix-post-rating" id="elpix-post-rating" value="0">
		</span>
	</p>
	<?php
}

function foobar_func( $atts ){
	return "foo and bar";
}


/** 
 *	Displaying average stars shortcode to display stars where ever it is possible
 *
 *	@author Kay Köhler <kk@elpix.de> 
 */
add_shortcode( 'elpix_average_rating', 'elpix_rate_post_show_average_rating' );
function elpix_rate_post_show_average_rating() 
{
	$commentrating_average = elpix_rate_post_get_average_rating();
	$commentrating = '<p class="comment-rating">';
	for( $i=1; $i <= $commentrating_average; $i++ ) {
		$commentrating .= '<span class="star_set" ></span>';
	}
	for( $j=1; $j <= 5+1-$i; $j++ ) {
		$commentrating .= '<span class="star_not_set" ></span>';
	}
	$text = $commentrating.'</p>'.$text;
	return $text;
}

/** 
 *	Get uprounded average rating of a post
 *
 *	@author Kay Köhler <kk@elpix.de> 
 */
function elpix_rate_post_get_average_rating() 
{
	global $post;
	$overall_ratings = 0;
	$count_ratings = 0;
	
	$args = array(
	'post_id' => $post->ID,
	'status' => 'approve',
	'meta_key' => 'elpix-post-rating');
	$ratings = get_comments( $args );
	foreach ( $ratings as $rating ) {
		$overall_ratings += $rating->meta_value;
	}
	
	$count_ratings = count($ratings);
	
	if ( $overall_ratings == 0 || $count_ratings == 0 ) {
		return 0;
	}
	else 
	{
		$average_count = $overall_ratings / $count_ratings ;
		$average_count = round($average_count, 0, PHP_ROUND_HALF_UP);
		return $average_count;	
	}
}

/**
 * 
 *	Saves rating in comment_meta data as elpix-post-rating
 *
 *	@author Kay Köhler <kk@elpix.de>
 */
add_action( 'comment_post', 'elpix_rate_post_save_comment_rating_data' );
function elpix_rate_post_save_comment_rating_data( $comment_id ) 
{
	if ( ( isset( $_POST['elpix-post-rating'] ) ) && ( $_POST['elpix-post-rating'] != '') ) {
		$rating = wp_filter_nohtml_kses( $_POST['elpix-post-rating'] );
	}
	add_comment_meta( $comment_id, 'elpix-post-rating', $rating );
}

/**
 * 
 * 	Add the filter to check whether the comment meta data has been filled
 * 
 *	@author Kay Köhler <kk@elpix.de>
 */
add_filter( 'preprocess_comment', 'elpix_rate_post_verify_comment_rating_data' );
function elpix_rate_post_verify_comment_rating_data( $ratingdata )
{
	if ( !( is_numeric($_POST['elpix-post-rating']) && $_POST['elpix-post-rating'] > 0 &&  $_POST['elpix-post-rating'] <= 5 ) ) {
		wp_die( __( 'Fehler: Sie haben keine Bewertung abgegeben. Bitte dr√ºcken Sie den zur√ºck Button Ihres Browers und schicken Sie Ihren Kommentar mit einer Bewertung ab.', 'elpix-rpic') );
	}
	return $ratingdata;
}

/**
 * 
 *	Add the comment meta to the comment text at the beginning
 * 
 *	TODO: Option to choose where the comment meta has to show up
 *	@author Kay Köhler <kk@elpix.de>
 */
add_filter( 'comment_text', 'elpix_rate_post_modify_comment' );
function elpix_rate_post_modify_comment( $text )
{
	$commentrating = get_comment_meta( get_comment_ID(), 'elpix-post-rating', true );

	if ( $commentrating ) 
	{
		$commentrating_text = '<p class="comment-rating">';
		for( $i=1; $i <= $commentrating; $i++ ) {
			$commentrating_text .= '<span class="star_set" ></span>';
		}
		for( $j=1; $j <= 5+1-$i; $j++ ) {
			$commentrating_text .= '<span class="star_not_set" ></span>';
		}
		$text = $commentrating_text.'</p>'.$text;
		return $text;
	} else {
		return $text;
	}
}

/**
 * 
 *	Add a meta box to comment editing screen
 *   
 *	@author Kay Köhler <kk@elpix.de>
 */
add_action( 'add_meta_boxes_comment', 'elpix_rate_post_extend_comment_add_meta_box' );
function elpix_rate_post_extend_comment_add_meta_box() {
    add_meta_box( 'title', __( 'Bewertung', 'elpix-rpic' ), 'elpix_rate_post_rating_meta_box', 'comment', 'normal', 'high' );
}

/**
 * 
 *	Add edit funktionality to meta box
 *   
 *	@author Kay Köhler <kk@elpix.de>
 */
function elpix_rate_post_rating_meta_box ( $comment ) 
{
    $rating = get_comment_meta( $comment->comment_ID, 'elpix-post-rating', true );
    wp_nonce_field( 'extend_comment_update', 'extend_comment_update', false );
    ?>
    <p>
        <label for="rating"><?php _e( 'Bewertung', 'elpix-rpic' ); ?>:</label>
		<span class="commentratingbox">
		<?php for( $i=1; $i <= 5; $i++ ) {
			echo '<span class="commentrating"><input type="radio" name="elpix-post-rating" id="elpix-post-rating" value="'. $i .'"';
			if ( $rating == $i ) echo ' checked="checked"';
			echo ' />'. $i .' </span>';
			}
		?>
		</span>
    </p>
    <?php
}

/**
 * 
 *	Update comment meta data from comment editing screen
 *  
 *  @author Kay Köhler <kk@elpix.de>
 */
add_action( 'edit_comment', 'elpix_rate_post_rating_edit_rating' );
function elpix_rate_post_rating_edit_rating( $comment_id ) 
{
    if( !isset( $_POST['extend_comment_update'] ) || ! wp_verify_nonce( $_POST['extend_comment_update'], 'extend_comment_update' ) ) {
    	return;	
    }
	
    if ( ( isset( $_POST['elpix-post-rating'] ) ) && ( $_POST['elpix-post-rating'] != '') ) 
    {
		$rating = wp_filter_nohtml_kses( $_POST['elpix-post-rating'] );
		update_comment_meta( $comment_id, 'elpix-post-rating', $rating );
    }
	else {
		delete_comment_meta( $comment_id, 'elpix-post-rating' );
	}
}

